/*
side-matter.js
Version 0.8

Plugin: Side Matter
Author: Christopher Setzer
URI: http://wordpress.org/extend/plugins/side-matter/
License: GPLv2
*/

/* These variables obtain their values from the settings fields in `side-matter.php`. */
var isResponsive = side_matter.is_responsive; // If true, reposition notes on resize/zoom (boolean)
var useEffects = side_matter.use_effects; // If true, enable jQuery fade effects when positioning notes (boolean)
var noteAdjust = side_matter.note_adjust; // Distance to arbitrarily offset note position, in px (integer)
var htmlClass = side_matter.html_class; // Class to use when selecting Side Matter tags (string; default: 'side-matter')

var isResizing; // Used for resize-timeout function

function placeNotes() {
	for (n = 1, noteCount = jQuery('li.' + htmlClass + '-note').length; n <= noteCount; n++) { // Iterate through notes and position each
		var ref = 'a.' + htmlClass + '-ref-' + n; // Reference anchor
		var note = 'li.' + htmlClass + '-note-' + n; // Sidenote
		var refPosition = jQuery(ref).position().top; // Position of reference anchor
		var notePosition = jQuery(note).position().top; // Position of sidenote
		var noteOffset = refPosition - notePosition - noteAdjust; // Get current offset from reference to note, minus noteAdjust
		var finalOffset = (noteOffset < 0) ? 0 : noteOffset; // If offset is negative, set to 0 (prevents layout problems)
		jQuery(note).css('marginTop', finalOffset); // Position note
	}
}

jQuery(document).ready(function() {
	jQuery('ol.' + htmlClass + '-list').css('opacity', 0); // Make notes briefly transparent to prevent unsightly flickering on load
});

jQuery(window).load(function() { // Position notes and fade in
	for (i = 1; i <= 2; i++) placeNotes(); // Loop twice to correct any misplacements on first load
	if (useEffects == 1) {
		jQuery('ol.' + htmlClass + '-list').fadeTo(200, 1);
	} else {
		jQuery('ol.' + htmlClass + '-list').css('opacity', 1);
	}
});

if (isResponsive == 1) {
	jQuery(window).resize(function() { // Reposition notes on resize/zoom
		if (useEffects == 1) jQuery('li.' + htmlClass + '-note').fadeTo(20, 0.2);
		var timeoutInterval = 500; // Time (in ms) to throttle the re-positioning loop, preventing script overload on resize (default: 500)
		function doneResizing() {
			placeNotes();
			if (useEffects == 1) jQuery('li.' + htmlClass + '-note').fadeTo(200, 1);
		}
		clearTimeout(isResizing);
		isResizing = setTimeout(doneResizing, timeoutInterval);
	});
}
